export MASTER_PORT=$((12000 + $RANDOM % 20000))
export OMP_NUM_THREADS=1

JOB_NAME='l16_ptk710_ftk710_ftk400_ftmitv1_f8_res224'
OUTPUT_DIR="$(dirname $0)/$JOB_NAME"
LOG_DIR="./logs/${JOB_NAME}"
PREFIX='your_data_path'
DATA_PATH='your_data_path/mitv1'
MODEL_PATH='your_model_path/l16_ptk710_ftk710_ftk400_ftmitv1_f8_res224.pth'

PARTITION='video'
GPUS=16
GPUS_PER_NODE=8
CPUS_PER_TASK=14

srun -p $PARTITION \
        --job-name=${JOB_NAME} \
        --gres=gpu:${GPUS_PER_NODE} \
        --ntasks=${GPUS} \
        --ntasks-per-node=${GPUS_PER_NODE} \
        --cpus-per-task=${CPUS_PER_TASK} \
        python run_class_finetuning.py \
        --model vit_large_patch16_224 \
        --data_path ${DATA_PATH} \
        --prefix ${PREFIX} \
        --data_set 'mitv1_sparse' \
        --nb_classes 339 \
        --finetune ${MODEL_PATH} \
        --log_dir ${OUTPUT_DIR} \
        --output_dir ${OUTPUT_DIR} \
        --batch_size 32 \
        --num_sample 1 \
        --input_size 224 \
        --short_side_size 224 \
        --save_ckpt_freq 100 \
        --num_frames 8 \
        --num_workers 12 \
        --warmup_epochs 5 \
        --tubelet_size 1 \
        --epochs 20 \
        --lr 1e-4 \
        --drop_path 0.2 \
        --layer_decay 0.85 \
        --use_checkpoint \
        --checkpoint_num 12 \
        --opt adamw \
        --opt_betas 0.9 0.999 \
        --weight_decay 0.05 \
        --test_num_segment 4 \
        --test_num_crop 3 \
        --dist_eval \
        --enable_deepspeed \
        --test_best